@@ -43,60 +43,60 @@ pub fn new_logger() -> Logger {
 #[macro_export]
 macro_rules! trace(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::trace!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Trace, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::trace!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Trace, "", $($args)+)
     };
 );
 
 #[macro_export]
 macro_rules! debug(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::debug!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Debug, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::debug!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Debug, "", $($args)+)
     };
 );
 
 #[macro_export]
 macro_rules! info(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::info!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Error, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::info!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Error, "", $($args)+)
     };
 );
 
 #[macro_export]
 macro_rules! warn(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::warn!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Warning, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::warn!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Warning, "", $($args)+)
     };
 );
 
 #[macro_export]
 macro_rules! error(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::error!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Error, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::error!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Error, "", $($args)+)
     };
 );
 
 #[macro_export]
 macro_rules! crit(
     (#$tag:expr, $($args:tt)+) => {
-        $crate::slog::crit!($crate::LOGGER, $tag, $($args)+)
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Critical, $tag, $($args)+)
     };
-    ($l:expr, $($args:tt)+) => {
-        $crate::slog::crit!($crate::LOGGER, "", $($args)+)
+    ($($args:tt)+) => {
+        $crate::slog::log!($crate::LOGGER, $crate::slog::Level::Critical, "", $($args)+)
     };
 );
 
@@ -134,3 +134,9 @@ mod format {
         }
     }
 }
+
+#[test]
+fn test_simple_info() {
+    info!("test"; "q" => 2);
+    info!("test");
+}
